clear;
close all;
clc;

M_s = 250; % Kg
k_s = 5000;% N/m
a_s = 1000;% N*s/m

A = [ 0 , 1 ; -k_s / M_s , -a_s / M_s ];	

autoval = eig( A ); disp(autoval)

%% tempo di risposta
lambdaD=max(real(autoval));   % parte reale dellautovalore dominante
TD=-1/lambdaD;                % costante di tempo dominante
TR=5*TD                       % tempo di risosta

%% salita del passeggero
m=80; g=9.81;
b=[0 -m*g/(4*M_s)]';
c=[1 0];
d=0;
sys_sedile=ss(A,b,c,d);
T=linspace(0,2*TR,100);
U=ones(size(T));
pos_sedile=lsim(sys_sedile,U,T);
figure; plot(T,pos_sedile);
xlabel('tempo [s]'); ylabel('posizione del sedile [m]');
title('salita del passeggero');

Eq_pas=-inv(A)*b*1
Y_pas=c*Eq_pas+d*1

%% simulazione della rampa
B = [ 0 , 0 ; k_s / M_s , a_s / M_s ];
c = [ 1 0 ];
d = [ 0 0 ];
sys_sedile_2 = ss( A , B , c , d );

%% alta velocit
vel = 50 / 3.6;	% m/s
[ x_strada , x_dot_strada , t_strada ] = genera_rampa( vel );
[ pos_sedile_2 , t_sim , st_sim ] = lsim( sys_sedile_2 , [ x_strada ; x_dot_strada ] , t_strada );

figure
plot( t_sim , pos_sedile_2 )
grid on
xlabel( 'tempo [s]' )
ylabel( 'posizione del sedile [m]' )
hold on
plot( t_sim,x_strada , 'r' )
legend( 'posizione sedile' , 'posizione rampa' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )
axis([0 15 0 0.2])

%% bassa velocit
vel = 5 / 3.6;	% m/s
[ x_strada , x_dot_strada , t_strada ] = genera_rampa( vel );
[ pos_sedile_2 , t_sim , st_sim ] = lsim( sys_sedile_2 , [ x_strada ; x_dot_strada ] , t_strada );

figure
plot( t_sim , pos_sedile_2 )
grid on
xlabel( 'tempo [s]' )
ylabel( 'posizione del sedile [m]' )
hold on
plot( t_sim,x_strada , 'r' )
legend( 'posizione sedile' , 'posizione rampa' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )
axis([0 15 0 0.2])

%% bassissima velocit
vel = 1 / 3.6;	% m/s
[ x_strada , x_dot_strada , t_strada ] = genera_rampa( vel );
[ pos_sedile_2 , t_sim , st_sim ] = lsim( sys_sedile_2 , [ x_strada ; x_dot_strada ] , t_strada );

figure
plot( t_sim , pos_sedile_2 )
grid on
xlabel( 'tempo [s]' )
ylabel( 'posizione del sedile [m]' )
hold on
plot( t_sim,x_strada , 'r' )
legend( 'posizione sedile' , 'posizione rampa' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )
axis([0 15 0 0.2])

%% alta velocit
vel=50/3.6;					% m/s 
[x_strada,x_dot_strada,t_strada]=genera_rampa(vel);
[pos_sedile_2,t_sim,st_sim]=lsim(sys_sedile_2,[x_strada;x_dot_strada],t_strada);
acc_sedile=(-a_s*(st_sim(:,2)-x_dot_strada')-k_s*(st_sim(:,1)-x_strada'))/M_s;
figure; plot(t_sim , acc_sedile);
grid on;
xlabel( 'tempo [s]' );
ylabel( 'accelerazione del sedile [m/s^2]' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )

%% bassa velocit
vel=5/3.6;					% m/s 
[x_strada,x_dot_strada,t_strada]=genera_rampa(vel);
[pos_sedile_2,t_sim,st_sim]=lsim(sys_sedile_2,[x_strada;x_dot_strada],t_strada);
acc_sedile=(-a_s*(st_sim(:,2)-x_dot_strada')-k_s*(st_sim(:,1)-x_strada'))/M_s;
figure; plot(t_sim , acc_sedile);
grid on;
xlabel( 'tempo [s]' );
ylabel( 'accelerazione del sedile [m/s^2]' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )

%% bassissima velocit
vel=1/3.6;					% m/s 
[x_strada,x_dot_strada,t_strada]=genera_rampa(vel);
[pos_sedile_2,t_sim,st_sim]=lsim(sys_sedile_2,[x_strada;x_dot_strada],t_strada);
acc_sedile=(-a_s*(st_sim(:,2)-x_dot_strada')-k_s*(st_sim(:,1)-x_strada'))/M_s;
figure; plot(t_sim , acc_sedile);
grid on;
xlabel( 'tempo [s]' );
ylabel( 'accelerazione del sedile [m/s^2]' );
title( sprintf( 'velocit = %i km/h',vel*3.6 ) )